<?php

namespace App\Entity;

use App\Repository\RemoteCalendarRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: RemoteCalendarRepository::class)]
class RemoteCalendar extends AbstractEntity
{
    use NameableTrait;

    /**
     * @var Collection<int, OrganizationalUnit>
     */
    #[ORM\OneToMany(mappedBy: 'remoteCalendar', targetEntity: OrganizationalUnit::class)]
    private Collection $organizationalUnits;

    /**
     * @var Collection<int, RemoteCalendarRule>
     */
    #[ORM\OneToMany(mappedBy: 'remoteCalendar', targetEntity: RemoteCalendarRule::class)]
    private Collection $rules;

    public function __construct()
    {
        parent::__construct();
        $this->rules = new ArrayCollection();
    }

    public function getOrganizationalUnits(): Collection
    {
        return $this->organizationalUnits;
    }

    public function setOrganizationalUnits(Collection $organizationalUnits): void
    {
        $this->organizationalUnits = $organizationalUnits;
    }

    /**
     * @return Collection<int, RemoteCalendarRule>
     */
    public function getRules(): Collection
    {
        return $this->rules;
    }

    public function addRule(RemoteCalendarRule $rule): static
    {
        if (!$this->rules->contains($rule)) {
            $this->rules->add($rule);
            $rule->setRemoteCalendar($this);
        }

        return $this;
    }

    public function removeRule(RemoteCalendarRule $rule): static
    {
        if ($this->rules->removeElement($rule)) {
            // set the owning side to null (unless already changed)
            if ($rule->getRemoteCalendar() === $this) {
                $rule->setRemoteCalendar(null);
            }
        }

        return $this;
    }
}
